.. $Id: objectives.rst 919 2012-06-12 22:10:09Z jemian $

Objectives
==========

A. Document SPEC macro source code files

  #. macro definitions (def, rdef, and cdef)
  #. function definitions
  #. global variable definitions
  #. local variable definitions
  #. array variable definitions
  #. constant definitions
  #. ReST-formatted comments (usually contain API or usage info)
  #. optional source code highlighting
  
B. Build cross-referenced WWW site and PDF documentation
C. Provide a test file for development.
D. Provide useful examples in documentation.
